@@ -198,7 +198,6 @@ module Encoders
           else
             styles = [k]
           end
-          type = styles.first
           classes = styles.map { |c| Tokens::ClassOfKind[c] }
           if classes.first == :NO_HIGHLIGHT and not hint
             h[k] = false
@@ -222,7 +221,7 @@ module Encoders
     end
 
     def finish options
-      not_needed = @opened.shift
+      @opened.shift
       @out << '</span>' * @opened.size
       unless @opened.empty?
         warn '%d tokens still open: %p' % [@opened.size, @opened]
@@ -264,7 +263,7 @@ module Encoders
         if @opened.empty?
           # nothing to close
         else
-          if $DEBUG and (@opened.size == 1 or @opened.last != type)
+          if $CODERAY_DEBUG and (@opened.size == 1 or @opened.last != type)
             raise 'Malformed token stream: Trying to close a token (%p) \
               that is not open. Open are: %p.' % [type, @opened[1..-1]]
           end
@@ -276,20 +275,24 @@ module Encoders
       when :begin_line
         @opened[0] = type
         if style = @css_style[@opened]
-          @out << style.sub('<span', '<div')
+          if style['class="']
+            @out << style.sub('class="', 'class="line ')
+          else
+            @out << style.sub('>', ' class="line">')
+          end
         else
-          @out << '<div>'
+          @out << '<span class="line">'
         end
         @opened << type
       when :end_line
         if @opened.empty?
           # nothing to close
         else
-          if $DEBUG and (@opened.size == 1 or @opened.last != type)
+          if $CODERAY_DEBUG and (@opened.size == 1 or @opened.last != type)
             raise 'Malformed token stream: Trying to close a line (%p) \
               that is not open. Open are: %p.' % [type, @opened[1..-1]]
           end
-          @out << '</div>'
+          @out << '</span>'
           @opened.pop
         end
       
