@@ -68,12 +68,16 @@ module CodeRay
 
         def normify code
           code = code.to_s
-          if code.respond_to? :force_encoding
-            begin
-              code.force_encoding 'utf-8'
-              code[/\z/]  # raises an ArgumentError when code contains a non-UTF-8 char
-            rescue ArgumentError
-              code.force_encoding 'binary'
+          if code.respond_to?(:encoding) && (code.encoding.name != 'UTF-8' || !code.valid_encoding?)
+            code = code.dup
+            original_encoding = code.encoding
+            code.force_encoding 'Windows-1252'
+            unless code.valid_encoding?
+              code.force_encoding original_encoding
+              if code.encoding.name == 'UTF-8'
+                code.encode! 'UTF-16BE', :invalid => :replace, :undef => :replace, :replace => '?'
+              end
+              code.encode! 'UTF-8', :invalid => :replace, :undef => :replace, :replace => '?'
             end
           end
           code.to_unix
@@ -144,7 +148,12 @@ module CodeRay
 
       def string= code
         code = Scanner.normify(code)
-        super code
+        if defined?(RUBY_DESCRIPTION) && RUBY_DESCRIPTION['rubinius 1.0.1']
+          reset_state
+          @string = code
+        else
+          super code
+        end
         reset_instance
       end
 
@@ -200,7 +209,7 @@ module CodeRay
         return 0 if pos <= 0
         string = string()
         if string.respond_to?(:bytesize) && (defined?(@bin_string) || string.bytesize != string.size)
-          @bin_string ||= string.dup.force_encoding(:binary)
+          @bin_string ||= string.dup.force_encoding('binary')
           string = @bin_string
         end
         pos - (string.rindex(?\n, pos) || 0)
@@ -271,6 +280,14 @@ surrounding code:
           string[pos, ambit],
         ]
       end
+      
+      # Shorthand for scan_until(/\z/).
+      # This method also avoids a JRuby 1.9 mode bug.
+      def scan_rest
+        rest = self.rest
+        terminate
+        rest
+      end
 
     end
 
