@@ -89,7 +89,7 @@ module Scanners
 
       until eos?
 
-        if (match = scan_until(/(?=#{START_OF_RUBY})/o) || scan_until(/\z/)) and not match.empty?
+        if (match = scan_until(/(?=#{START_OF_RUBY})/o) || scan_rest) && !match.empty?
           @html_scanner.tokenize match
 
         elsif match = scan(/#{NITRO_VALUE_BLOCK}/o)
