@@ -13,22 +13,14 @@ module Scanners
     
     def scan_tokens tokens, options
       
-      value_expected = nil
       state = :initial
-      key_indent = indent = 0
+      key_indent = 0
       
       until eos?
         
         kind = nil
         match = nil
-        
-        if bol?
-          key_indent = nil
-          if $DEBUG
-            indent = check(/ +/) ? matched.size : 0
-            tokens << [indent.to_s, :debug]
-          end
-        end
+        key_indent = nil if bol?
         
         if match = scan(/ +[\t ]*/)
           kind = :space
@@ -128,8 +120,11 @@ module Scanners
         
         match ||= matched
         
-        raise_inspect 'Error token %p in line %d' % [[match, kind], line], tokens if $DEBUG && !kind
-        raise_inspect 'Empty token', tokens unless match
+        if $CODERAY_DEBUG and not kind
+          raise_inspect 'Error token %p in line %d' %
+            [[match, kind], line], tokens, state
+        end
+        raise_inspect 'Empty token', tokens, state unless match
         
         tokens << [match, kind]
         
